<?php

class BazaUslugKategoriaPeer extends BaseBazaUslugKategoriaPeer
{

    static public function translateFieldName($name, $fromType, $toType)
    {
        if($name == 'nazwa')
            return $name;
        else
            return parent::translateFieldName($name, $fromType, $toType);
    }

    /**
     * metoda zwracajaca liste widocznych kategorii przefiltrowana zgodnie z parametrami
     * @param       int $typ_id id typu zgodnie z app.yml
     * @param       int $kat_id id kategorii
     * @param       int $spec_id id specjalisty
     * @param       int $uslg_id id uslugi
     * @param       string $fraza fraza wystepujaca w nazwie lub opisie
     * @param       string $usluga fraza wystepujaca w nazwie lub opisie uslugi
     * @return      array lista widocznych kategorii uslug
     * @author      Tomasz Glowinski, 2014
     */
    static public function getFilteredList($typ_id = null, $kat_id = null, $spec_id = null, $uslg_id = null, $fraza = '', $usluga = '')
    {
        $culture = sfContext::getInstance()->getUser()->getCulture();
                
        $c = new CriteriaExt();
        $c->addJoin(self::ID, BazaUslugKategoriaI18nPeer::ID, Criteria::LEFT_JOIN);        
        $c->add(BazaUslugKategoriaI18nPeer::CULTURE, $culture); // w tym jezyku
        
        if(!empty($spec_id))
        {
            $c->addJoin(self::ID, BazaUslugMapaSpecKatPeer::KAT_ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugMapaSpecKatPeer::SPEC_ID, BazaUslugSpecjalistaPeer::ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugSpecjalistaPeer::ID, BazaUslugSpecjalistaI18nPeer::ID, Criteria::LEFT_JOIN);
            $c->add(BazaUslugSpecjalistaI18nPeer::CULTURE, $culture); // w tym jezyku
        }
        
        if(!empty($uslg_id))
        {
            $c->addJoin(self::ID, BazaUslugMapaUslgKatPeer::KAT_ID, Criteria::LEFT_JOIN);       
            $c->addJoin(BazaUslugMapaUslgKatPeer::USLG_ID, BazaUslugUslugaPeer::ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugUslugaPeer::ID, BazaUslugUslugaI18nPeer::ID, Criteria::LEFT_JOIN);
            $c->add(BazaUslugUslugaI18nPeer::CULTURE, $culture); // w tym jezyku
        }        
        
        $c->add(self::PORTAL_ID, sfConfig::get('portal')->getId()); // z tego portalu
        $c->add(self::STATUS_ID, 1); // opublikowane
        
        if(!empty($typ_id))
            $c->add(self::TYP, $typ_id);
            
        if(!empty($kat_id))
            $c->add(self::ID, $kat_id);
        
        if(!empty($spec_id))
            $c->add(BazaUslugMapaSpecKatPeer::SPEC_ID, $spec_id);
        
        if(!empty($uslg_id))
            $c->add(BazaUslugMapaUslgKatPeer::USLG_ID, $uslg_id);
        
        if(!empty($fraza))
        {
            $c_tmp = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::NAZWA, '%'.$fraza.'%', Criteria::LIKE);
            $c2 = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::OPIS, '%'.$fraza.'%', Criteria::LIKE);
            $c3 = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::TAGI, '%'.$fraza.'%', Criteria::LIKE);
            $c_tmp->addOr($c2)->addOr($c3);
            
            $fraza_parts = explode(' ', $fraza);
            foreach($fraza_parts as $part)
            {
                $c1 = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::NAZWA, '%'.$part.'%', Criteria::LIKE);
                $c2 = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::OPIS, '%'.$part.'%', Criteria::LIKE);
                $c3 = $c->getNewCriterion(BazaUslugKategoriaI18nPeer::TAGI, '%'.$part.'%', Criteria::LIKE);
                $c_tmp->addOr($c1)->addOr($c2)->addOr($c3);
            }
            $c->addAnd($c_tmp);
        }
        
        $c->addAscendingOrderByColumn(BazaUslugKategoriaI18nPeer::NAZWA);
        $c->addGroupByColumn(self::ID);        
        
        return self::doSelectWithI18n($c, $culture);
    }
    
    static public function getStructure()
    {
        $types = sfConfig::get('app_uslg_types');
        
        $structure = array();
        
        foreach($types as $typ_id => $typ_name)
        {
            $list_by_type = self::getFilteredList($typ_id);
            if(!empty($list_by_type))
                $structure[$typ_id] = $list_by_type;
        }
            
        return $structure;
    }
    
    public static function doSelectByType()
    {
        $types = sfConfig::get('app_uslg_types');
        
        $structure = array();
        
        foreach($types as $typ_id => $typ_name)
            $structure[] = new BazaUslugTypPeer($typ_id, $typ_name);
            
        return $structure;
    }
    
     /**
     * metoda wyciagajaca ostatnio dodane kategorie
     * @param       int $limit ilosc ostatnich kategorii
     * @return      array lista ostatnio dodanych kategorii
     * @author      Krzysztof Trzcinski, 2014
     */
    public static function getKategory($limit = 5)
    {
        $c = new Criteria();    
        $c->add(self::PORTAL_ID, sfConfig::get('portal')->getId());
        $c->add(self::STATUS_ID, 1);        
        $c->addDescendingOrderByColumn(self::CREATED_AT);        
        $c->setLimit($limit);                 
        return self::doSelect($c);        
    }
}

class BazaUslugTypPeer
{
    private $typ_id = null;
    private $typ_name = null;

    public function __construct($typ_id, $typ_name)
    {
        $this->setTypId($typ_id);
        $this->setTypName($typ_name);
    }

    public function setTypId($id)
    {
        $this->typ_id = $id;
    }

    public function getTypId()
    {
        return $this->typ_id;
    }

    public function setTypName($name)
    {
        $this->typ_name = $name;
    }

    public function getTypName()
    {
        return $this->typ_name;
    }

    public function getPrimaryKey()
    {
        return $this->typ_id;
    }
    
    public function __toString()
    {
        return $this->typ_name;
    }    
   
}
