<?php

class BazaUslugUslugaPeer extends BaseBazaUslugUslugaPeer
{
    static public function translateFieldName($name, $fromType, $toType)
	{
        if($name == 'nazwa')
            return $name;
        else
            return parent::translateFieldName($name, $fromType, $toType);
	}
    
    /**
     * metoda zwracajaca liste widocznych uslug przefiltrowana zgodnie z parametrami
     * @param       int $typ_id id typu zgodnie z app.yml
     * @param       int $kat_id id kategorii
     * @param       int $spec_id id specjalisty
     * @param       int $uslg_id id uslugi
     * @param       string $fraza fraza wystepujaca w nazwie lub opisie
     * @param       string $usluga fraza wystepujaca w nazwie lub opisie uslugi
     * @return      array lista uslug przefiltrowana zgodnie z parametrami
     * @author      Tomasz Glowinski, 2014
     */
    static public function getFilteredList($typ_id = null, $kat_id = null, $spec_id = null, $uslg_id = null, $fraza = '', $usluga = '')
    {
        $culture = sfContext::getInstance()->getUser()->getCulture();
                
        $c = new CriteriaExt();
        $c->addJoin(self::ID, BazaUslugUslugaI18nPeer::ID, Criteria::LEFT_JOIN);
        $c->add(BazaUslugUslugaI18nPeer::CULTURE, $culture); // w tym jezyku
        $c->add(self::PORTAL_ID, sfConfig::get('portal')->getId()); // z tego portalu
        $c->add(self::STATUS_ID, 1); // opublikowane
        
        if(!empty($typ_id) || !empty($kat_id))
        {
            $c->addJoin(self::ID, BazaUslugMapaUslgKatPeer::USLG_ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugMapaUslgKatPeer::KAT_ID, BazaUslugKategoriaPeer::ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugKategoriaPeer::ID, BazaUslugKategoriaI18nPeer::ID, Criteria::LEFT_JOIN);
            $c->add(BazaUslugKategoriaI18nPeer::CULTURE, $culture); // w tym jezyku
        }
        
        if(!empty($spec_id))
        {
            $c->addJoin(self::ID, BazaUslugMapaUslgSpecPeer::USLG_ID, Criteria::LEFT_JOIN);       
            $c->addJoin(BazaUslugMapaUslgSpecPeer::SPEC_ID, BazaUslugSpecjalistaPeer::ID, Criteria::LEFT_JOIN);
            $c->addJoin(BazaUslugSpecjalistaPeer::ID, BazaUslugSpecjalistaI18nPeer::ID, Criteria::LEFT_JOIN);
            $c->add(BazaUslugSpecjalistaI18nPeer::CULTURE, $culture); // w tym jezyku
        }
                
        if(!empty($typ_id))
            $c->add(BazaUslugKategoriaPeer::TYP, $typ_id);
        
        if(!empty($kat_id))
            $c->add(BazaUslugMapaUslgKatPeer::KAT_ID, $kat_id);
        
        if(!empty($spec_id))
            $c->add(BazaUslugMapaUslgSpecPeer::SPEC_ID, $spec_id);
        
        if(!empty($uslg_id))
            $c->add(self::ID, $uslg_id);
        
        if(!empty($fraza))
        {
            $c_tmp = $c->getNewCriterion(BazaUslugUslugaI18nPeer::NAZWA, '%'.$fraza.'%', Criteria::LIKE);
            $c2 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::OPIS, '%'.$fraza.'%', Criteria::LIKE);
            $c3 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::TAGI, '%'.$fraza.'%', Criteria::LIKE);
            $c_tmp->addOr($c2)->addOr($c3);
            
            $fraza_parts = explode(' ', $fraza);
            foreach($fraza_parts as $part)
            {
                $c1 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::NAZWA, '%'.$part.'%', Criteria::LIKE);
                $c2 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::OPIS, '%'.$part.'%', Criteria::LIKE);
                $c3 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::TAGI, '%'.$part.'%', Criteria::LIKE);
                $c_tmp->addOr($c1)->addOr($c2)->addOr($c3);
            }
            $c->addAnd($c_tmp);
        }
        
        if(!empty($usluga))
        {
            $c_tmp = $c->getNewCriterion(BazaUslugUslugaI18nPeer::NAZWA, '%'.$usluga.'%', Criteria::LIKE);
            
            $usluga_parts = explode(' ', $usluga);
            foreach($usluga_parts as $part)
            {
                $c1 = $c->getNewCriterion(BazaUslugUslugaI18nPeer::NAZWA, '%'.$part.'%', Criteria::LIKE);
                $c_tmp->addOr($c1);
            }
            $c->addAnd($c_tmp);
        }
        
        $c->addGroupByColumn(self::ID);
        $c->addAscendingOrderByColumn(BazaUslugUslugaI18nPeer::NAZWA);
        
        return self::doSelectWithI18n($c, $culture);
    }
    
    /**
     * metoda wyciagajaca ostatnio dodane uslugi
     * @param       int $limit ilosc ostatnich uslug
     * @return      array lista ostatnio dodanych uslug
     * @author      Krzysztof Trzcinski, 2014
     */
    public static function getNajnowsze($limit = 5)
    {
        $c = new Criteria();       
        $c->add(self::PORTAL_ID, sfConfig::get('portal')->getId());
        $c->add(self::STATUS_ID , 1);
        $c->addDescendingOrderByColumn(self::CREATED_AT);
        $c->setLimit($limit);                 
        return self::doSelect($c);        
    }
            
}
